pitchtools.inversion_equivalent_chromatic_interval_class_number_dictionary
==========================================================================

.. autofunction:: abjad.tools.pitchtools.inversion_equivalent_chromatic_interval_class_number_dictionary.inversion_equivalent_chromatic_interval_class_number_dictionary
   :noindex:
